#
# spec file for package secvarctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global make_parms OPENSSL=1 DEBUG=1
Name:           secvarctl
VCS: https://src.suse.de/SLFO-pool/secvarctl#09ab50e58e2859e5b2772734776ae98047aeb616ac1a7485df2b1f7c06ed11f3
Version:        1.1.0+git1.1d8b86b
Release:        160000.1.4
Summary:        Suite of tools to manipulate and generate Secure Boot variables on POWER
License:        Apache-2.0
URL:            https://github.com/open-power/secvarctl
Source:         %{name}-%{version}.tar.gz
BuildRequires:  openssl-devel
ExclusiveArch:  ppc64 ppc64le

%description
The purpose of this tool is to simplify and automate the process of reading and writing secure boot keys.
secvarctl allows the user to communicate, via terminal commands, with the keys efficiently.

%prep
%autosetup

%build
%make_build %{make_parms}

%install
%make_install %{make_parms}

%files
%license LICENSE
%doc README.md
%{_bindir}/secvarctl
%{_mandir}/man1/secvarctl.1%{?ext_man}

%changelog
* Thu Nov 28 2024 msuchanek@suse.de
- Update to version 1.1.0+git1.1d8b86b (jsc#PED-9893):
  * external/libstb-secvar: version bump for 3k RSA key support
  * guest/read: don't attempt to print an ESL from a zero-sized buffer
* Wed Feb 14 2024 msuchanek@suse.com
- Update to version v1.0.0 (jsc#PED-5449):
  * guest/generate: fix multiple input/output format specifier argument parsing
  * guest/read: fix segfault in read -c caused by empty variable name
  * guest/verify: only print default PK in get_current_esl_data if verbose is set
* Thu Dec 14 2023 msuchanek@suse.com
- Update to version 1.0.0~rc3:
  * Guest/verify: fix misbehaviour of verify and write with -p
  * Guest/generate: trustedcadb variable allow only CA certificates
  * Guest/Verify: -w option allowed when use -u with -p
  * guest/generate: fix potential null reference in pk/append special case
* Fri Oct 13 2023 msuchanek@suse.com
- Update to version 1.0.0~rc2+git1.1f96bad:
  * guest/read: return early if next esd cannot be parsed
  * guest: Remove x509 SHA GUID functions and macros
  * guest/generate: change --append option to be a boolean based on presence
  * guest/read: allow paths with or without a trailing slash
  * Makefile: Fix installation after source reorganization
- Remove upstreamed secvarctl-install.patch
* Mon Oct  2 2023 msuchanek@suse.com
- Update to version 1.0.0~rc1+git0.a180a56:
  * guest/util: Add crypto id to signature list
  * secvarctl: guest secure boot variable backend
  * secvarctl: reorganised host secure boot variable backend
- Fix installation: secvarctl-install.patch
* Tue Nov 22 2022 msuchanek@suse.com
- Update to version 0.3+git13.76db7a7:
  * Update crypto calling functions to expect success return codes
  * crypto-gnutls.c: Unify return codes
  * crypto-mbedtls.c: Unify error codes
  * crypto-openssl.c: Unify return codes
  * crypto: Add support for GnuTLS
  * crypto: Fix openssl implementation of crypto_x509_is_RSA
  * crypto: Enable compatability with OpenSSL V3
  * crypto: Catch possible uninitialized return code
* Thu Sep 23 2021 msuchanek@suse.com
- Version 0.2+git31 released as 0.3 (jsc#SLE-18126).
* Mon Sep 20 2021 msuchanek@suse.com
- Update to version 0.2+git31~26ea751:
- Remove workaround for wrong man page location - fixed upstream.
* Wed Jun 16 2021 msuchanek@suse.com
- Initial packaging (jsc#SLE-18126).
